import { ParserSyntaxError } from '../../shared';
export type FindModifier = {
    method: 'skip' | 'filter' | 'min' | 'max' | 'returnKey' | 'showRecordId' | 'limit' | 'hint';
    parameters: unknown;
} | {
    method: 'sort';
    parameters?: unknown;
    options?: unknown;
};
export interface FindCommand {
    method: 'find';
    collectionName: string;
    parameters?: unknown;
    options?: unknown;
    explain?: {
        parameters?: unknown;
    };
    modifiers: FindModifier[];
}
export interface FindOneCommand {
    method: 'findOne';
    collectionName: string;
    parameters?: unknown;
    options?: unknown;
}
export interface FindOneAndDeleteCommand {
    method: 'findOneAndDelete';
    collectionName: string;
    parameters: unknown;
    options?: unknown;
}
export interface FindOneAndReplaceCommand {
    method: 'findOneAndReplace';
    collectionName: string;
    parameters: unknown;
    replacement: unknown;
    options?: unknown;
}
export interface FindOneAndUpdateCommand {
    method: 'findOneAndUpdate';
    collectionName: string;
    parameters: unknown;
    newValues: unknown;
    options?: unknown;
}
export interface InsertOneCommand {
    method: 'insertOne';
    collectionName: string;
    document: unknown;
    options: unknown;
}
export interface InsertManyCommand {
    method: 'insertMany';
    collectionName: string;
    documents: unknown;
    options: unknown;
}
export type Command = FindCommand | FindOneCommand | FindOneAndDeleteCommand | FindOneAndReplaceCommand | FindOneAndUpdateCommand | InsertOneCommand | InsertManyCommand;
export interface ParsingError {
    type: 'parsingError';
    message: string;
}
export interface UnexpectedError {
    type: 'unexpectedError';
    message: unknown;
}
export type ExtractMongoCommandsFromQueryResult = {
    commands: Command[];
} | {
    parseSyntaxErrors: ParserSyntaxError[];
} | {
    parseCommandsError: ParsingError | UnexpectedError;
};
export declare function extractMongoCommandsFromQuery(query: string): ExtractMongoCommandsFromQueryResult;
